@@ -18,7 +18,6 @@ from botocore.model import (
 )
 from botocore.response import StreamingBody
 from botocore.session import Session as BotocoreSession
-
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
@@ -282,11 +281,7 @@ class ShapeParser:
         if not shape.enum:
             return Type.str
 
-        type_literal = TypeLiteral()
-        for option in shape.enum:
-            type_literal.add_literal_child(option)
-
-        return type_literal
+        return TypeLiteral(shape.name, [option for option in shape.enum])
 
     def _parse_shape_map(self, shape: MapShape) -> FakeAnnotation:
         type_subscript = TypeSubscript(Type.Dict)
@@ -490,6 +485,12 @@ class ShapeParser:
 
         return result
 
+    @staticmethod
+    def _get_arg_from_target(target: str) -> str:
+        if "[" not in target:
+            return target
+        return target.split("[")[0]
+
     def _get_resource_method(
         self, resource_name: str, action_name: str, action_shape: Dict[str, Any]
     ) -> Method:
@@ -507,11 +508,11 @@ class ShapeParser:
         if "request" in action_shape:
             operation_name = action_shape["request"]["operation"]
             operation_shape = self._get_operation(operation_name)
-            skip_argument_names: List[str] = [
-                i["target"]
+            skip_argument_names = set(
+                self._get_arg_from_target(i["target"])
                 for i in action_shape["request"].get("params", {})
                 if i["source"] == "identifier"
-            ]
+            )
             if operation_shape.input_shape is not None:
                 for argument in self._parse_arguments(
                     resource_name,
