@@ -2,7 +2,6 @@
 Boto3 client Paginator.
 """
 from botocore.paginate import Paginator as Boto3Paginator
-
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.service_name import ServiceName
@@ -42,7 +41,10 @@ class Paginator(ClassRecord):
             docstring=self.docstring,
             arguments=[
                 Argument("self", None),
-                Argument("operation_name", TypeLiteral(self.operation_name)),
+                Argument(
+                    "operation_name",
+                    TypeLiteral(f"{self.name}Name", [self.operation_name]),
+                ),
             ],
             return_type=ExternalImport(
                 source=ImportString(
