@@ -92,6 +92,19 @@ def write_service_package(
                 ),
             )
         )
+    if package.literals:
+        file_paths.extend(
+            (
+                (
+                    package_path / ServiceModuleName.literals.stub_file_name,
+                    module_templates_path / ServiceModuleName.literals.template_name,
+                ),
+                (
+                    package_path / ServiceModuleName.literals.file_name,
+                    module_templates_path / ServiceModuleName.literals.template_name,
+                ),
+            )
+        )
     if package.typed_dicts:
         file_paths.extend(
             (
@@ -113,8 +126,8 @@ def write_service_package(
             service_name=package.service_name,
         )
         if file_path.suffix in [".py", ".pyi"]:
-            content = blackify(content, file_path)
             content = sort_imports(content, package.service_name.module_name, extension="pyi")
+            content = blackify(content, file_path)
 
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
